@@ -1,6 +1,6 @@
 package Ubic::Service::Hypnotoad;
 {
-  $Ubic::Service::Hypnotoad::VERSION = '0.002';
+  $Ubic::Service::Hypnotoad::VERSION = '0.1';
 }
 # ABSTRACT: Ubic service module for Mojolicious Hypnotoad
 
@@ -12,6 +12,9 @@ use parent qw(Ubic::Service::Skeleton);
 use Ubic::Result qw(result);
 use File::Basename;
 use Time::HiRes qw(time);
+use Capture::Tiny qw(:all);
+
+
 
 
 sub new {
@@ -82,7 +85,7 @@ sub status_impl {
 sub start_impl {
 	my $self = shift;
 
-	local %ENV = (%ENV, %{ $self->{'env'} // {} });
+	local %ENV = (%ENV, %{ $self->{'env'} });
 	system($self->{'bin'}, $self->{'app'});
 	$self->{'start_time'} = time;
 	$self->{'stop_time'} = undef;
@@ -93,8 +96,11 @@ sub start_impl {
 sub stop_impl {
 	my $self = shift;
 
-	local %ENV = (%ENV, %{ $self->{'env'} // {} });
-	system($self->{'bin'}, '-s', $self->{'app'});
+	local %ENV = (%ENV, %{ $self->{'env'} });
+	my (undef, $stderr) = capture {
+		system($self->{'bin'}, '-s', $self->{'app'});
+	};
+	print $stderr	if length $stderr;
 	$self->{'stop_time'} = time;
 	$self->{'start_time'} = undef;
 
@@ -123,6 +129,9 @@ sub timeout_options {
 }
 
 
+
+
+
 1;
 
 __END__
@@ -135,7 +144,49 @@ Ubic::Service::Hypnotoad - Ubic service module for Mojolicious Hypnotoad
 
 =head1 VERSION
 
-version 0.002
+version 0.1
+
+=head1 SYNOPSIS
+
+    use Ubic::Service::Hypnotoad;
+    return Ubic::Service::Hypnotoad->new({
+        bin => '/usr/bin/hypnotoad', # optional, defaults to 'hypnotoad'
+        app => '/home/www/mysite.app',
+        pid_file => '/var/log/mysite.pid', # optional, defaults to a hypnotoad.pid file lying next to "app"
+        env => { # optional environment variables
+            MOJO_FLAG_A => 1,
+            MOJO_CONFIG => '...',
+        },
+    });
+
+=head1 DESCRIPTION
+
+This service is a common ubic wrap for launching your applications with Hypnotoad.
+
+=head1 ACTIONS
+
+=head2 status
+
+Get status of service.
+
+=head2 start
+
+Start service.
+
+=head2 stop
+
+Stop service
+
+=head2 reload
+
+Send a USR2 signal to the process, to have it do an "automatic hot deployment".
+
+=head1 BUGS
+
+If you have a Github account, report your issues at
+L<https://github.com/akarelas/ubic-service-hypnotoad/issues>.
+I will be notified, and then you'll automatically be notified of progress on
+your bug as I make changes.
 
 =head1 AUTHOR
 
